@@ -33,7 +33,7 @@ Author: Ralph Mor, X Consortium
 #include "ICElibint.h"
 
 static Bool auth_valid (const char *auth_name, int num_auth_names,
-			char **auth_names, int *index_ret);
+			const char **auth_names, int *index_ret);
 
 
 /*
@@ -55,9 +55,9 @@ static Bool auth_valid (const char *auth_name, int num_auth_names,
 
 void
 _IceGetPoAuthData (
-	char		*protocolName,
-	char		*networkId,
-	char		*authName,
+	const char	*protocolName,
+	const char	*networkId,
+	const char	*authName,
 	unsigned short	*authDataLenRet,
 	char		**authDataRet
 )
@@ -86,9 +86,9 @@ _IceGetPoAuthData (
 
 void
 _IceGetPaAuthData (
-	char		*protocolName,
-	char		*networkId,
-	char		*authName,
+	const char	*protocolName,
+	const char	*networkId,
+	const char	*authName,
 	unsigned short	*authDataLenRet,
 	char		**authDataRet
 )
@@ -125,12 +125,12 @@ _IceGetPaAuthData (
 
 void
 _IceGetPoValidAuthIndices (
-	char	*protocol_name,
-	char	*network_id,
-	int	num_auth_names,
-	char	**auth_names,
-	int	*num_indices_ret,
-	int	*indices_ret		/* in/out arg */
+	const char	*protocol_name,
+	const char	*network_id,
+	int		num_auth_names,
+	const char	**auth_names,
+	int		*num_indices_ret,
+	int		*indices_ret		/* in/out arg */
 )
 {
     FILE    		*auth_file;
@@ -184,12 +184,12 @@ _IceGetPoValidAuthIndices (
 
 void
 _IceGetPaValidAuthIndices (
-	char	*protocol_name,
-	char	*network_id,
-	int	num_auth_names,
-	char	**auth_names,
-	int	*num_indices_ret,
-	int	*indices_ret		/* in/out arg */
+	const char	*protocol_name,
+	const char	*network_id,
+	int		num_auth_names,
+	const char	**auth_names,
+	int		*num_indices_ret,
+	int		*indices_ret		/* in/out arg */
 )
 {
     int			index_ret;
@@ -232,7 +232,7 @@ _IceGetPaValidAuthIndices (
 
 static Bool
 auth_valid (const char *auth_name, int num_auth_names,
-	    char **auth_names, int *index_ret)
+	    const char **auth_names, int *index_ret)
 
 {
     /*
@@ -246,7 +246,7 @@ auth_valid (const char *auth_name, int num_auth_names,
 	{
 	    break;
 	}
-   
+
     if (i < num_auth_names)
     {
 	*index_ret = i;
